@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 20251011.1825
-;; Package-Revision: 09d07714904f
+;; Package-Version: 20251122.1915
+;; Package-Revision: 68169beaebc1
 ;; Package-Requires: (
 ;;     (emacs  "26.1")
 ;;     (compat "30.1"))
@@ -135,7 +135,10 @@ This variable has to be set before `no-littering' is loaded.")
     (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq erc-dcc-get-default-directory    (var "erc/dcc/"))
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
-    (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
+    (setq erc-startup-file-list            (list (etc "erc/startup.el")
+                                                 (etc "erc/startup")
+                                                 ".ercrc.el"
+                                                 ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
     ;; This controls where `eshell-history-file-name' is places.
     ;; Other files belong in "etc/" so theme their variables directly.
@@ -201,6 +204,7 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'newsticker  `(make-directory ,(var "newsticker/") t))
     (eval-after-load 'org         `(make-directory ,(var "org/") t))
     (eval-after-load 'shadowfile  `(make-directory ,(var "shadow/") t))
+    (eval-after-load 'treesit     `(push ,(var "treesit/") treesit-extra-load-path))
 
 ;;; Third-party packages
 
